@@ -21,25 +21,12 @@
 #ifndef __GSD_COLOR_MANAGER_H
 #define __GSD_COLOR_MANAGER_H
 
-#include <glib-object.h>
+#include <gio/gio.h>
 
 G_BEGIN_DECLS
 
 #define GSD_TYPE_COLOR_MANAGER         (gsd_color_manager_get_type ())
-#define GSD_COLOR_MANAGER_ERROR        (gsd_color_manager_error_quark ())
-G_DECLARE_FINAL_TYPE (GsdColorManager, gsd_color_manager, GSD, COLOR_MANAGER, GObject)
-
-enum
-{
-        GSD_COLOR_MANAGER_ERROR_FAILED
-};
-
-GQuark                  gsd_color_manager_error_quark         (void);
-
-GsdColorManager *       gsd_color_manager_new                 (void);
-gboolean                gsd_color_manager_start               (GsdColorManager *manager,
-                                                               GError         **error);
-void                    gsd_color_manager_stop                (GsdColorManager *manager);
+G_DECLARE_FINAL_TYPE (GsdColorManager, gsd_color_manager, GSD, COLOR_MANAGER, GApplication)
 
 G_END_DECLS
 
