@@ -20,17 +20,12 @@
 #ifndef __GSD_DATETIME_MANAGER_H
 #define __GSD_DATETIME_MANAGER_H
 
-#include <glib.h>
-#include <glib-object.h>
+#include <gio/gio.h>
 
 G_BEGIN_DECLS
 
 #define GSD_TYPE_DATETIME_MANAGER         (gsd_datetime_manager_get_type ())
-G_DECLARE_FINAL_TYPE (GsdDatetimeManager, gsd_datetime_manager, GSD, DATETIME_MANAGER, GObject)
-
-GsdDatetimeManager *gsd_datetime_manager_new (void);
-gboolean gsd_datetime_manager_start (GsdDatetimeManager *manager, GError **error);
-void gsd_datetime_manager_stop (GsdDatetimeManager *manager);
+G_DECLARE_FINAL_TYPE (GsdDatetimeManager, gsd_datetime_manager, GSD, DATETIME_MANAGER, GApplication)
 
 G_END_DECLS
 
