@@ -50,7 +50,7 @@ static const gchar introspection_xml[] =
 "</node>";
 
 struct _GsdHousekeepingManager {
-        GObject          parent;
+        GApplication parent;
 
         GSettings *settings;
         guint long_term_cb;
@@ -67,10 +67,7 @@ struct _GsdHousekeepingManager {
 static void     gsd_housekeeping_manager_class_init  (GsdHousekeepingManagerClass *klass);
 static void     gsd_housekeeping_manager_init        (GsdHousekeepingManager      *housekeeping_manager);
 
-G_DEFINE_TYPE (GsdHousekeepingManager, gsd_housekeeping_manager, G_TYPE_OBJECT)
-
-static gpointer manager_object = NULL;
-
+G_DEFINE_TYPE (GsdHousekeepingManager, gsd_housekeeping_manager, G_TYPE_APPLICATION)
 
 typedef struct {
         GDateTime *now;  /* (owned) */
@@ -420,15 +417,17 @@ register_manager_dbus (GsdHousekeepingManager *manager)
                    manager);
 }
 
-gboolean
-gsd_housekeeping_manager_start (GsdHousekeepingManager *manager,
-                                GError                **error)
+static void
+gsd_housekeeping_manager_startup (GApplication *app)
 {
+        GsdHousekeepingManager *manager = GSD_HOUSEKEEPING_MANAGER (app);
         gchar *dir;
 
         g_debug ("Starting housekeeping manager");
         gnome_settings_profile_start (NULL);
 
+        register_manager_dbus (manager);
+
         /* Create ~/.local/ as early as possible */
         (void) g_mkdir_with_parents(g_get_user_data_dir (), 0700);
 
@@ -455,14 +454,16 @@ gsd_housekeeping_manager_start (GsdHousekeepingManager *manager,
 
         manager->systemd_notify = g_object_new (GSD_TYPE_SYSTEMD_NOTIFY, NULL);
 
-        gnome_settings_profile_end (NULL);
+        G_APPLICATION_CLASS (gsd_housekeeping_manager_parent_class)->startup (app);
 
-        return TRUE;
+        gnome_settings_profile_end (NULL);
 }
 
-void
-gsd_housekeeping_manager_stop (GsdHousekeepingManager *manager)
+static void
+gsd_housekeeping_manager_shutdown (GApplication *app)
 {
+        GsdHousekeepingManager *manager = GSD_HOUSEKEEPING_MANAGER (app);
+
         g_debug ("Stopping housekeeping manager");
 
         if (manager->name_id != 0) {
@@ -496,22 +497,17 @@ gsd_housekeeping_manager_stop (GsdHousekeepingManager *manager)
 
         g_clear_object (&manager->settings);
         gsd_ldsm_clean ();
-}
 
-static void
-gsd_housekeeping_manager_finalize (GObject *object)
-{
-        gsd_housekeeping_manager_stop (GSD_HOUSEKEEPING_MANAGER (object));
-
-        G_OBJECT_CLASS (gsd_housekeeping_manager_parent_class)->finalize (object);
+        G_APPLICATION_CLASS (gsd_housekeeping_manager_parent_class)->shutdown (app);
 }
 
 static void
 gsd_housekeeping_manager_class_init (GsdHousekeepingManagerClass *klass)
 {
-        GObjectClass *object_class = G_OBJECT_CLASS (klass);
+        GApplicationClass *application_class = G_APPLICATION_CLASS (klass);
 
-        object_class->finalize = gsd_housekeeping_manager_finalize;
+        application_class->startup = gsd_housekeeping_manager_startup;
+        application_class->shutdown = gsd_housekeeping_manager_shutdown;
 
         notify_init ("gnome-settings-daemon");
 }
@@ -520,19 +516,3 @@ static void
 gsd_housekeeping_manager_init (GsdHousekeepingManager *manager)
 {
 }
-
-GsdHousekeepingManager *
-gsd_housekeeping_manager_new (void)
-{
-        if (manager_object != NULL) {
-                g_object_ref (manager_object);
-        } else {
-                manager_object = g_object_new (GSD_TYPE_HOUSEKEEPING_MANAGER, NULL);
-                g_object_add_weak_pointer (manager_object,
-                                           (gpointer *) &manager_object);
-
-                register_manager_dbus (manager_object);
-        }
-
-        return GSD_HOUSEKEEPING_MANAGER (manager_object);
-}
