@@ -130,7 +130,7 @@ static const gchar introspection_xml2[] =
 
 struct _GsdScreensaverProxyManager
 {
-        GObject                  parent;
+        GApplication             parent;
 
         GsdSessionManager       *session;
         GDBusConnection         *connection;
@@ -145,11 +145,8 @@ struct _GsdScreensaverProxyManager
 
 static void     gsd_screensaver_proxy_manager_class_init  (GsdScreensaverProxyManagerClass *klass);
 static void     gsd_screensaver_proxy_manager_init        (GsdScreensaverProxyManager      *screensaver_proxy_manager);
-static void     gsd_screensaver_proxy_manager_finalize    (GObject             *object);
 
-G_DEFINE_TYPE (GsdScreensaverProxyManager, gsd_screensaver_proxy_manager, G_TYPE_OBJECT)
-
-static gpointer manager_object = NULL;
+G_DEFINE_TYPE (GsdScreensaverProxyManager, gsd_screensaver_proxy_manager, G_TYPE_APPLICATION)
 
 static void
 name_vanished_cb (GDBusConnection            *connection,
@@ -360,12 +357,16 @@ register_manager_dbus (GsdScreensaverProxyManager *manager)
                    manager);
 }
 
-gboolean
-gsd_screensaver_proxy_manager_start (GsdScreensaverProxyManager *manager,
-                                     GError               **error)
+static void
+gsd_screensaver_proxy_manager_startup (GApplication *app)
 {
+        GsdScreensaverProxyManager *manager = GSD_SCREENSAVER_PROXY_MANAGER (app);
+
         g_debug ("Starting screensaver-proxy manager");
         gnome_settings_profile_start (NULL);
+
+        register_manager_dbus (manager);
+
         manager->session =
                 gnome_settings_bus_get_session_proxy ();
         manager->watch_ht = g_hash_table_new_full (g_str_hash,
@@ -376,69 +377,47 @@ gsd_screensaver_proxy_manager_start (GsdScreensaverProxyManager *manager,
                                                           g_direct_equal,
                                                           NULL,
                                                           (GDestroyNotify) g_free);
+
+        G_APPLICATION_CLASS (gsd_screensaver_proxy_manager_parent_class)->startup (app);
+
         gnome_settings_profile_end (NULL);
-        return TRUE;
 }
 
-void
-gsd_screensaver_proxy_manager_stop (GsdScreensaverProxyManager *manager)
+static void
+gsd_screensaver_proxy_manager_shutdown (GApplication *app)
 {
+        GsdScreensaverProxyManager *manager = GSD_SCREENSAVER_PROXY_MANAGER (app);
+
         g_debug ("Stopping screensaver_proxy manager");
         g_clear_object (&manager->session);
         g_clear_pointer (&manager->watch_ht, g_hash_table_destroy);
         g_clear_pointer (&manager->cookie_ht, g_hash_table_destroy);
+
+        g_clear_handle_id (&manager->name_id, g_bus_unown_name);
+
+        g_clear_object (&manager->connection);
+
+        if (manager->bus_cancellable != NULL) {
+                g_cancellable_cancel (manager->bus_cancellable);
+                g_clear_object (&manager->bus_cancellable);
+        }
+
+        g_clear_pointer (&manager->introspection_data, g_dbus_node_info_unref);
+        g_clear_pointer (&manager->introspection_data2, g_dbus_node_info_unref);
+
+        G_APPLICATION_CLASS (gsd_screensaver_proxy_manager_parent_class)->shutdown (app);
 }
 
 static void
 gsd_screensaver_proxy_manager_class_init (GsdScreensaverProxyManagerClass *klass)
 {
-        GObjectClass   *object_class = G_OBJECT_CLASS (klass);
+        GApplicationClass *application_class = G_APPLICATION_CLASS (klass);
 
-        object_class->finalize = gsd_screensaver_proxy_manager_finalize;
+        application_class->startup = gsd_screensaver_proxy_manager_startup;
+        application_class->shutdown = gsd_screensaver_proxy_manager_shutdown;
 }
 
 static void
 gsd_screensaver_proxy_manager_init (GsdScreensaverProxyManager *manager)
 {
 }
-
-static void
-gsd_screensaver_proxy_manager_finalize (GObject *object)
-{
-        GsdScreensaverProxyManager *manager;
-
-        g_return_if_fail (object != NULL);
-        g_return_if_fail (GSD_IS_SCREENSAVER_PROXY_MANAGER (object));
-
-        manager = GSD_SCREENSAVER_PROXY_MANAGER (object);
-
-        g_return_if_fail (manager != NULL);
-
-        gsd_screensaver_proxy_manager_stop (manager);
-
-        if (manager->name_id != 0) {
-                g_bus_unown_name (manager->name_id);
-                manager->name_id = 0;
-        }
-        g_clear_object (&manager->connection);
-        g_clear_object (&manager->bus_cancellable);
-        g_clear_pointer (&manager->introspection_data, g_dbus_node_info_unref);
-        g_clear_pointer (&manager->introspection_data2, g_dbus_node_info_unref);
-
-        G_OBJECT_CLASS (gsd_screensaver_proxy_manager_parent_class)->finalize (object);
-}
-
-GsdScreensaverProxyManager *
-gsd_screensaver_proxy_manager_new (void)
-{
-        if (manager_object != NULL) {
-                g_object_ref (manager_object);
-        } else {
-                manager_object = g_object_new (GSD_TYPE_SCREENSAVER_PROXY_MANAGER, NULL);
-                g_object_add_weak_pointer (manager_object,
-                                           (gpointer *) &manager_object);
-                register_manager_dbus (manager_object);
-        }
-
-        return GSD_SCREENSAVER_PROXY_MANAGER (manager_object);
-}
