@@ -31,7 +31,7 @@
 
 #include "gnome-settings-bus.h"
 #include "gnome-settings-profile.h"
-#include "gsd-enums.h"
+#include "gnome-settings-daemon/gsd-enums.h"
 #include "gsd-usb-protection-manager.h"
 
 #define PRIVACY_SETTINGS "org.gnome.desktop.privacy"
@@ -68,7 +68,7 @@
 
 struct _GsdUsbProtectionManager
 {
-        GObject             parent;
+        GApplication        parent;
         guint               start_idle_id;
         GDBusNodeInfo      *introspection_data;
         GSettings          *settings;
@@ -102,12 +102,7 @@ typedef enum {
         POLICY_APPLIED_ATTRIBUTES
 } UsbGuardPolicyApplied;
 
-
-static void gsd_usb_protection_manager_finalize (GObject *object);
-
-G_DEFINE_TYPE (GsdUsbProtectionManager, gsd_usb_protection_manager, G_TYPE_OBJECT)
-
-static gpointer manager_object = NULL;
+G_DEFINE_TYPE (GsdUsbProtectionManager, gsd_usb_protection_manager, G_TYPE_APPLICATION)
 
 #define GSD_DBUS_NAME "org.gnome.SettingsDaemon"
 #define GSD_DBUS_PATH "/org/gnome/SettingsDaemon"
@@ -376,7 +371,7 @@ static void update_usb_protection_store (GsdUsbProtectionManager *manager,
                  * changed it. When this happens we set to false the control value. */
                 if ((g_strcmp0 (key, APPLY_POLICY) == 0 && protection_level == G_DESKTOP_USB_PROTECTION_ALWAYS)) {
                         g_settings_set (settings, USB_PROTECTION, "b", FALSE);
-                        g_warning ("We don't control anymore USBGuard because the configuration changed externally.");
+                        g_warning ("We do not control USBGuard any longer because the configuration changed externally.");
                 }
         }
 }
@@ -408,10 +403,11 @@ show_notification (GsdUsbProtectionManager *manager,
                 return;
         }
 
-        manager->notification = notify_notification_new (summary, body, "drive-removable-media-symbolic");
+        manager->notification = notify_notification_new (summary, body, NULL);
         notify_notification_set_app_name (manager->notification, _("USB Protection"));
         notify_notification_set_hint (manager->notification, "transient", g_variant_new_boolean (TRUE));
         notify_notification_set_hint_string (manager->notification, "x-gnome-privacy-scope", "system");
+        notify_notification_set_hint (manager->notification, "image-path", g_variant_new_string ("drive-removable-media-symbolic"));
         notify_notification_set_timeout (manager->notification, NOTIFY_EXPIRES_DEFAULT);
         notify_notification_set_urgency (manager->notification, NOTIFY_URGENCY_CRITICAL);
         g_signal_connect_object (manager->notification,
@@ -533,15 +529,15 @@ on_screen_locked (GsdScreenSaver          *screen_saver,
         if (error) {
                 if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
                         return;
-                g_warning ("Couldn't lock screen: %s", error->message);
+                g_warning ("Could not lock screen: %s", error->message);
         }
 
         authorize_device (manager, device_id);
         show_notification (manager,
                            _("New USB device"),
-                           _("New device has been detected while the session was not locked. "
-                             "If you did not plug anything, check your system for any suspicious device."));
-
+                           _("New USB device has been activated while the session was not locked. "
+                             "If you did not intend to insert any device, "
+                             "check your system for any suspicious gadgets and remove them."));
 }
 
 
@@ -682,7 +678,7 @@ on_usbguard_signal (GDBusProxy *proxy,
                         guint device_id;
                         show_notification (manager,
                                            _("New device detected"),
-                                           _("Either one of your existing devices has been reconnected or a new one has been plugged in. "
+                                           _("Either one of your existing devices has been reconnected or a new one has been inserted. "
                                              "If you did not do it, check your system for any suspicious device."));
                         g_variant_get_child (parameters, POLICY_APPLIED_DEVICE_ID, "u", &device_id);
                         authorize_device (manager, device_id);
@@ -725,7 +721,7 @@ on_usbguard_signal (GDBusProxy *proxy,
                                 show_notification (manager,
                                                    _("USB device blocked"),
                                                    _("The new inserted device has been blocked because the USB protection is active. "
-                                                     "If you want to activate the device, disable the USB protection and re-plug "
+                                                     "If you want to activate the device, disable the USB protection and re-insert "
                                                      "the device."));
                         }
                 } else {
@@ -1240,10 +1236,11 @@ start_usb_protection_idle_cb (GsdUsbProtectionManager *manager)
         return FALSE;
 }
 
-gboolean
-gsd_usb_protection_manager_start (GsdUsbProtectionManager *manager,
-                                  GError                 **error)
+static void
+gsd_usb_protection_manager_startup (GApplication *app)
 {
+        GsdUsbProtectionManager *manager = GSD_USB_PROTECTION_MANAGER (app);
+
         gnome_settings_profile_start (NULL);
 
         manager->start_idle_id = g_idle_add ((GSourceFunc) start_usb_protection_idle_cb, manager);
@@ -1258,13 +1255,16 @@ gsd_usb_protection_manager_start (GsdUsbProtectionManager *manager,
                    (GAsyncReadyCallback) on_bus_gotten,
                    manager);
 
+        G_APPLICATION_CLASS (gsd_usb_protection_manager_parent_class)->startup (app);
+
         gnome_settings_profile_end (NULL);
-        return TRUE;
 }
 
-void
-gsd_usb_protection_manager_stop (GsdUsbProtectionManager *manager)
+static void
+gsd_usb_protection_manager_shutdown (GApplication *app)
 {
+        GsdUsbProtectionManager *manager = GSD_USB_PROTECTION_MANAGER (app);
+
         g_debug ("Stopping USB protection manager");
 
         if (manager->cancellable != NULL) {
@@ -1291,43 +1291,20 @@ gsd_usb_protection_manager_stop (GsdUsbProtectionManager *manager)
         g_clear_object (&manager->usb_protection_devices);
         g_clear_object (&manager->usb_protection_policy);
         g_clear_object (&manager->screensaver_proxy);
+
+        G_APPLICATION_CLASS (gsd_usb_protection_manager_parent_class)->shutdown (app);
 }
 
 static void
 gsd_usb_protection_manager_class_init (GsdUsbProtectionManagerClass *klass)
 {
-        GObjectClass *object_class = G_OBJECT_CLASS (klass);
+        GApplicationClass *application_class = G_APPLICATION_CLASS (klass);
 
-        object_class->finalize = gsd_usb_protection_manager_finalize;
+        application_class->startup = gsd_usb_protection_manager_startup;
+        application_class->shutdown = gsd_usb_protection_manager_shutdown;
 }
 
 static void
 gsd_usb_protection_manager_init (GsdUsbProtectionManager *manager)
 {
 }
-
-static void
-gsd_usb_protection_manager_finalize (GObject *object)
-{
-        GsdUsbProtectionManager *usb_protection_manager;
-
-        usb_protection_manager = GSD_USB_PROTECTION_MANAGER (object);
-        gsd_usb_protection_manager_stop (usb_protection_manager);
-
-        G_OBJECT_CLASS (gsd_usb_protection_manager_parent_class)->finalize (object);
-}
-
-GsdUsbProtectionManager *
-gsd_usb_protection_manager_new (void)
-{
-        g_debug ("Starting USB Protection");
-        if (manager_object != NULL) {
-                g_object_ref (manager_object);
-        } else {
-                manager_object = g_object_new (GSD_TYPE_USB_PROTECTION_MANAGER, NULL);
-                g_object_add_weak_pointer (manager_object,
-                                           (gpointer *) &manager_object);
-        }
-
-        return GSD_USB_PROTECTION_MANAGER (manager_object);
-}
